# usefulCommandLineTools
A Python Module with useful functions for creating a command line tool!

Keep in mind that some features may not work on all terminals, so be weary
of that when creating your app!
# WIP

### Progress
  * Added clear function. Clears console.
  * Added abilty to print colored text!
  

### Want to do
  * Add a text to ASCII art generator but I can't do it myself